--- CoreOperationAnd.java	Thu Aug  6 17:03:56 2009
+++ CoreOperationOr.java	Thu Aug  6 17:02:17 2009
@@ -20,32 +20,32 @@
 import org.apache.commons.jxpath.ri.InfoSetUtil;
 
 /**
- * Implementation of {@link Expression} for the operation "and".
+ * Implementation of {@link Expression} for the operation "or".
  *
  * @author Dmitri Plotnikov
  * @version $Revision: 652845 $ $Date: 2008-05-02 12:46:46 -0500 (Fri, 02 May 2008) $
  */
-public class CoreOperationAnd extends CoreOperation {
+public class CoreOperationOr extends CoreOperation {
 
     /**
      * Create a new CoreOperationAnd.
      * @param args to combine
      */
-    public CoreOperationAnd(Expression[] args) {
+    public CoreOperationOr(Expression[] args) {
         super(args);
     }
 
     public Object computeValue(EvalContext context) {
         for (int i = 0; i < args.length; i++) {
-            if (!InfoSetUtil.booleanValue(args[i].computeValue(context))) {
-                return Boolean.FALSE;
+            if (InfoSetUtil.booleanValue(args[i].computeValue(context))) {
+                return Boolean.TRUE;
             }
         }
-        return Boolean.TRUE;
+        return Boolean.FALSE;
     }
 
     protected int getPrecedence() {
-        return AND_PRECEDENCE;
+        return OR_PRECEDENCE;
     }
 
     protected boolean isSymmetric() {
@@ -53,6 +53,6 @@
     }
 
     public String getSymbol() {
-        return "and";
+        return "or";
     }
 }
@@ -20,32 +20,32 @@
 
     /**
-     * Create a new CoreOperationAnd.
-     * @param args to combine
+     * Create a new CoreOperationOr.
+     * @param args or'd Expression components
      */
